@@ -35,11 +35,7 @@ class HUBLogger:
 
     def _upload_model(self, epoch, is_best, weights):
         api_url = HUB_API_ROOT + "model-checkpoint"
-        payload = {
-            "modelId": self.model_id,
-            "epoch": epoch,
-            "isBest": bool(is_best)
-        }
+        payload = {"modelId": self.model_id, "epoch": epoch, "isBest": bool(is_best)}
         payload.update(self.auth.get_auth_string())
 
         with open(weights, "rb") as last:
