@@ -63,5 +63,7 @@ class YOLOv5Wrapper:
     @staticmethod
     def new_callback_handler():
         """Returns a YOLOv5 callback handler"""
-        _callback_handler = importlib.import_module("yolov5.utils.callbacks")
-        return _callback_handler.Callbacks()
+        from yolov5.utils.callbacks import Callbacks
+        return Callbacks()
+        # _callback_handler = importlib.import_module("yolov5.utils.callbacks")
+        # return _callback_handler.Callbacks()
